[Libreoffice-commits] core.git: sc/source

Albert Thuswaldner albert.thuswaldner at gmail.com
Thu Feb 12 01:55:23 PST 2015


 sc/source/core/data/dptabres.cxx |    2 
 sc/source/core/data/drwlayer.cxx |   52 +++++++++----------
 sc/source/core/data/fillinfo.cxx |  106 +++++++++++++++++++--------------------
 sc/source/core/data/markdata.cxx |    8 +-
 sc/source/core/data/patattr.cxx  |   51 +++++++++---------
 5 files changed, 109 insertions(+), 110 deletions(-)

New commits:
commit 16fd6c99f7e97e67991dfecd03684795320e47e9
Author: Albert Thuswaldner <albert.thuswaldner at gmail.com>
Date:   Sun Feb 8 20:37:15 2015 +0100

    Translated german comments in sc/source/core/data/
    
    Change-Id: I82ca987d5d74d8137b9ed02e085f390191344bb0
    Reviewed-on: https://gerrit.libreoffice.org/14371
    Reviewed-by: Caolán McNamara <caolanm at redhat.com>
    Tested-by: Caolán McNamara <caolanm at redhat.com>

diff --git a/sc/source/core/data/dptabres.cxx b/sc/source/core/data/dptabres.cxx
index 00eecec..cd78a5d 100644
--- a/sc/source/core/data/dptabres.cxx
+++ b/sc/source/core/data/dptabres.cxx
@@ -57,7 +57,7 @@ using ::com::sun::star::uno::Sequence;
 
 namespace {
 
-sal_uInt16 nFuncStrIds[12] =     // passend zum enum ScSubTotalFunc
+sal_uInt16 nFuncStrIds[12] =     // matching enum ScSubTotalFunc
 {
     0,                              // SUBTOTAL_FUNC_NONE
     STR_FUN_TEXT_AVG,               // SUBTOTAL_FUNC_AVE
diff --git a/sc/source/core/data/drwlayer.cxx b/sc/source/core/data/drwlayer.cxx
index 9d68ca3..1ec9d13 100644
--- a/sc/source/core/data/drwlayer.cxx
+++ b/sc/source/core/data/drwlayer.cxx
@@ -193,7 +193,7 @@ ScDrawLayer::ScDrawLayer( ScDocument* pDocument, const OUString& rName ) :
     bAdjustEnabled( true ),
     bHyphenatorSet( false )
 {
-    pGlobalDrawPersist = NULL;          // nur einmal benutzen
+    pGlobalDrawPersist = NULL;          // Only use once
 
     SfxObjectShell* pObjSh = pDocument ? pDocument->GetDocumentShell() : NULL;
     XColorListRef pXCol = XColorList::GetStdColorList();
@@ -239,7 +239,7 @@ ScDrawLayer::ScDrawLayer( ScDocument* pDocument, const OUString& rName ) :
     rAdmin.NewLayer(OUString("hidden"),   SC_LAYER_HIDDEN);
     // "Controls" is new - must also be created when loading
 
-    //  Link fuer URL-Fields setzen
+    // Set link for URL-Fields
     ScModule* pScMod = SC_MOD();
     Outliner& rOutliner = GetDrawOutliner();
     rOutliner.SetCalcFieldValueHdl( LINK( pScMod, ScModule, CalcFieldValueHdl ) );
@@ -267,7 +267,7 @@ ScDrawLayer::ScDrawLayer( ScDocument* pDocument, const OUString& rName ) :
     if( pDoc )
         EnableUndo( pDoc->IsUndoEnabled() );
 
-    //  URL-Buttons haben keinen Handler mehr, machen alles selber
+    //  URL-Buttons have no handler anymore, all is done by themselves
 
     if( !nInst++ )
     {
@@ -352,11 +352,11 @@ void ScDrawLayer::ScRemovePage( SCTAB nTab )
     if (bRecording)
     {
         SdrPage* pPage = GetPage(static_cast<sal_uInt16>(nTab));
-        AddCalcUndo(new SdrUndoDelPage(*pPage));        // Undo-Action wird Owner der Page
-        RemovePage( static_cast<sal_uInt16>(nTab) );                            // nur austragen, nicht loeschen
+        AddCalcUndo(new SdrUndoDelPage(*pPage));        // Undo-Action becomes the page owner
+        RemovePage( static_cast<sal_uInt16>(nTab) );    // just deliver, not deleting
     }
     else
-        DeletePage( static_cast<sal_uInt16>(nTab) );                            // einfach weg damit
+        DeletePage( static_cast<sal_uInt16>(nTab) );    // just get rid of it
 
     ResetTab(nTab, pDoc->GetTableCount()-1);
 }
@@ -383,7 +383,7 @@ void ScDrawLayer::ScCopyPage( sal_uInt16 nOldPos, sal_uInt16 nNewPos)
     SdrPage* pOldPage = GetPage(nOldPos);
     SdrPage* pNewPage = GetPage(nNewPos);
 
-    // kopieren
+    // Copying
 
     if (pOldPage && pNewPage)
     {
@@ -513,9 +513,9 @@ void ScDrawLayer::SetPageSize( sal_uInt16 nPageNo, const Size& rSize, bool bUpda
             Broadcast( ScTabSizeChangedHint( static_cast<SCTAB>(nPageNo) ) );   // SetWorkArea() an den Views
         }
 
-        // Detektivlinien umsetzen (an neue Hoehen/Breiten anpassen)
-        //  auch wenn Groesse gleich geblieben ist
-        //  (einzelne Zeilen/Spalten koennen geaendert sein)
+        // Implement Detective lines (adjust to new heights / widths)
+        //  even if size is still the same
+        //  (individual rows/columns can have been changed))
 
         bool bNegativePage = pDoc && pDoc->IsNegativePage( static_cast<SCTAB>(nPageNo) );
 
@@ -640,7 +640,7 @@ void ScDrawLayer::RecalcPos( SdrObject* pObj, ScDrawObjData& rData, bool bNegati
         TwipsToMM( aPos.X() );
         TwipsToMM( aPos.Y() );
 
-        //  Berechnung und Werte wie in detfunc.cxx
+        // Calculations and values as in detfunc.cxx
 
         Size aSize( (long)( TwipsToHmm( pDoc->GetColWidth( nCol1, nTab1) ) ),
                     (long)( TwipsToHmm( pDoc->GetRowHeight( nRow1, nTab1) ) ) );
@@ -880,7 +880,7 @@ bool ScDrawLayer::GetPrintArea( ScRange& rRange, bool bSetHor, bool bSetVer ) co
     long nStartX = LONG_MAX;
     long nStartY = LONG_MAX;
 
-    // Grenzen ausrechnen
+    // Calculate borders
 
     if (!bSetHor)
     {
@@ -957,7 +957,7 @@ bool ScDrawLayer::GetPrintArea( ScRange& rRange, bool bSetHor, bool bSetVer ) co
 
     if (bAny)
     {
-        OSL_ENSURE( nStartX<=nEndX && nStartY<=nEndY, "Start/End falsch in ScDrawLayer::GetPrintArea" );
+        OSL_ENSURE( nStartX<=nEndX && nStartY<=nEndY, "Start/End wrong in ScDrawLayer::GetPrintArea" );
 
         if (bSetHor)
         {
@@ -1065,7 +1065,7 @@ void ScDrawLayer::MoveArea( SCTAB nTab, SCCOL nCol1,SCROW nRow1, SCCOL nCol2,SCR
     if ( bNegativePage )
         aMove.X() = -aMove.X();
 
-    Point aTopLeft = aRect.TopLeft();       // Anfang beim Verkleinern
+    Point aTopLeft = aRect.TopLeft();       // Beginning when zoomed out
     if (bInsDel)
     {
         if ( aMove.X() != 0 && nDx < 0 )    // nDx counts cells, sign is independent of RTL
@@ -1074,7 +1074,7 @@ void ScDrawLayer::MoveArea( SCTAB nTab, SCCOL nCol1,SCROW nRow1, SCCOL nCol2,SCR
             aTopLeft.Y() += aMove.Y();
     }
 
-        //      Detektiv-Pfeile: Zellpositionen anpassen
+        //      Detectiv arrows: Adjust cell position
 
     MoveCells( nTab, nCol1,nRow1, nCol2,nRow2, nDx,nDy, bUpdateNoteCaptionPos );
 }
@@ -1205,7 +1205,7 @@ void ScDrawLayer::DeleteObjectsInSelection( const ScMarkData& rMark )
             if (nObjCount)
             {
                 size_t nDelCount = 0;
-                //  Rechteck um die ganze Selektion
+                //  Rectangle around the whole selection
                 Rectangle aMarkBound = pDoc->GetMMRect(
                             aMarkRange.aStart.Col(), aMarkRange.aStart.Row(),
                             aMarkRange.aEnd.Col(), aMarkRange.aEnd.Row(), nTab );
@@ -1232,7 +1232,7 @@ void ScDrawLayer::DeleteObjectsInSelection( const ScMarkData& rMark )
                     pObject = aIter.Next();
                 }
 
-                //  Objekte loeschen (rueckwaerts)
+                //  Delete objects (backwards)
 
                 if (bRecording)
                     for (size_t i=1; i<=nDelCount; ++i)
@@ -1950,21 +1950,21 @@ IMapObject* ScDrawLayer::GetHitIMapObject( SdrObject* pObj,
         Graphic     aGraphic;
         bool        bObjSupported = false;
 
-        if ( pObj->ISA( SdrGrafObj )  ) // einfaches Grafik-Objekt
+        if ( pObj->ISA( SdrGrafObj )  ) // Simple Graphics object
         {
             const SdrGrafObj*   pGrafObj = static_cast<const SdrGrafObj*>( pObj );
             const GeoStat&      rGeo = pGrafObj->GetGeoStat();
             const Graphic&      rGraphic = pGrafObj->GetGraphic();
 
-            // Drehung rueckgaengig
+            // Reverse rotation
             if ( rGeo.nRotationAngle )
                 RotatePoint( aRelPoint, aLogRect.TopLeft(), -rGeo.nSin, rGeo.nCos );
 
-            // Spiegelung rueckgaengig
+            // Reverse mirroring
             if ( static_cast<const SdrGrafObjGeoData*>( pGrafObj->GetGeoData() )->bMirrored )
                 aRelPoint.X() = aLogRect.Right() + aLogRect.Left() - aRelPoint.X();
 
-            // ggf. Unshear:
+            // Possible Unshear:
             if ( rGeo.nShearAngle )
                 ShearPoint( aRelPoint, aLogRect.TopLeft(), -rGeo.nTan );
 
@@ -1978,17 +1978,17 @@ IMapObject* ScDrawLayer::GetHitIMapObject( SdrObject* pObj,
 
             bObjSupported = true;
         }
-        else if ( pObj->ISA( SdrOle2Obj ) ) // OLE-Objekt
+        else if ( pObj->ISA( SdrOle2Obj ) ) // OLE object
         {
             // TODO/LEAN: working with visual area needs running state
             aGraphSize = static_cast<const SdrOle2Obj*>(pObj)->GetOrigObjSize();
             bObjSupported = true;
         }
 
-        // hat alles geklappt, dann HitTest ausfuehren
+        // If everything has worked out, then perform HitTest
         if ( bObjSupported )
         {
-            // relativen Mauspunkt berechnen
+            // Calculate relative mouse point
             aRelPoint -= aLogRect.TopLeft();
             pIMapObj = rImageMap.GetHitIMapObject( aGraphSize, aLogRect.GetSize(), aRelPoint );
         }
@@ -2026,7 +2026,7 @@ sal_Int32 ScDrawLayer::GetHyperlinkCount(SdrObject* pObj)
     sal_Int32 nHLCount = 0;
     ScMacroInfo* pMacroInfo = GetMacroInfo(pObj, false);
     if (pMacroInfo)
-        // MT IA2: GetHlink*( doesn|t exist in DEV300 anymore...
+        // MT IA2: GetHlink*( doesn't exist in DEV300 anymore...
         nHLCount = 0; // pMacroInfo->GetHlink().getLength() > 0 ? 1 : 0;
     return nHLCount;
 }
@@ -2046,7 +2046,7 @@ void ScDrawLayer::SetChanged( bool bFlg /* = true */ )
 
 SdrLayerID ScDrawLayer::GetControlExportLayerId( const SdrObject & ) const
 {
-    //  Layer fuer Export von Form-Controls in Versionen vor 5.0 - immer SC_LAYER_FRONT
+    //  Layer for export of Form-Controls in Versions before 5.0 - always SC_LAYER_FRONT
     return SC_LAYER_FRONT;
 }
 
diff --git a/sc/source/core/data/markdata.cxx b/sc/source/core/data/markdata.cxx
index 687f1ab..55537b2 100644
--- a/sc/source/core/data/markdata.cxx
+++ b/sc/source/core/data/markdata.cxx
@@ -146,7 +146,7 @@ void ScMarkData::SetMultiMarkArea( const ScRange& rRange, bool bMark )
     for (nCol=nStartCol; nCol<=nEndCol; nCol++)
         pMultiSel[nCol].SetMarkArea( nStartRow, nEndRow, bMark );
 
-    if ( bMultiMarked )                 // aMultiRange updaten
+    if ( bMultiMarked )                 // Update aMultiRange
     {
         if ( nStartCol < aMultiRange.aStart.Col() )
             aMultiRange.aStart.SetCol( nStartCol );
@@ -159,7 +159,7 @@ void ScMarkData::SetMultiMarkArea( const ScRange& rRange, bool bMark )
     }
     else
     {
-        aMultiRange = rRange;           // neu
+        aMultiRange = rRange;           // new
         bMultiMarked = true;
     }
 }
@@ -260,7 +260,7 @@ void ScMarkData::MarkToSimple()
         while ( nStartCol < nEndCol && !pMultiSel[nEndCol].HasMarks() )
             --nEndCol;
 
-        //  Zeilen werden nur aus MarkArray genommen
+        // Rows are only taken from MarkArray
         SCROW nStartRow, nEndRow;
         if ( pMultiSel[nStartCol].HasOneMark( nStartRow, nEndRow ) )
         {
@@ -531,7 +531,7 @@ bool ScMarkData::HasAnyMultiMarks() const
         if ( pMultiSel[nCol].HasMarks() )
             return true;
 
-    return false;       // nix
+    return false;       // no
 }
 
 void ScMarkData::InsertTab( SCTAB nTab )
diff --git a/sc/source/core/data/patattr.cxx b/sc/source/core/data/patattr.cxx
index 99a398f..dfcfa70 100644
--- a/sc/source/core/data/patattr.cxx
+++ b/sc/source/core/data/patattr.cxx
@@ -155,7 +155,7 @@ SfxPoolItem* ScPatternAttr::Create( SvStream& rStream, sal_uInt16 /* nVersion */
         short   eFamDummy;
         pStr = new OUString;
         *pStr = rStream.ReadUniOrByteString( rStream.GetStreamCharSet() );
-        rStream.ReadInt16( eFamDummy ); // wg. altem Dateiformat
+        rStream.ReadInt16( eFamDummy ); // due to old data format
     }
     else
         pStr = new OUString( ScGlobal::GetRscString(STR_STYLENAME_STANDARD) );
@@ -177,13 +177,13 @@ SvStream& ScPatternAttr::Store(SvStream& rStream, sal_uInt16 /* nItemVersion */)
 
     if ( pStyle )
         rStream.WriteUniOrByteString( pStyle->GetName(), rStream.GetStreamCharSet() );
-    else if ( pName )                   // wenn Style geloescht ist/war
+    else if ( pName )                   // when style is/was deleted
         rStream.WriteUniOrByteString( *pName, rStream.GetStreamCharSet() );
     else
         rStream.WriteUniOrByteString( ScGlobal::GetRscString(STR_STYLENAME_STANDARD),
                                     rStream.GetStreamCharSet() );
 
-    rStream.WriteInt16( SFX_STYLE_FAMILY_PARA );  // wg. altem Dateiformat
+    rStream.WriteInt16( SFX_STYLE_FAMILY_PARA );  // due to old data format
 
     GetItemSet().Store( rStream );
 
@@ -221,7 +221,7 @@ void ScPatternAttr::GetFont(
         const SfxItemSet* pCondSet, sal_uInt8 nScript,
         const Color* pBackConfigColor, const Color* pTextConfigColor )
 {
-    //  Items auslesen
+    // Read items
 
     const SvxFontItem* pFontAttr;
     sal_uInt32 nFontHeight;
@@ -324,7 +324,7 @@ void ScPatternAttr::GetFont(
             pItem = &rItemSet.Get( nLangId );
         eLang = static_cast<const SvxLanguageItem*>(pItem)->GetLanguage();
     }
-    else    // alles aus rItemSet
+    else    // Everything from rItemSet
     {
         pFontAttr = &static_cast<const SvxFontItem&>(rItemSet.Get( nFontId ));
         nFontHeight = static_cast<const SvxFontHeightItem&>(
@@ -356,7 +356,7 @@ void ScPatternAttr::GetFont(
     }
     OSL_ENSURE(pFontAttr,"Oops?");
 
-    //  auswerten
+    //  Evaluate
 
     //  FontItem:
 
@@ -371,7 +371,7 @@ void ScPatternAttr::GetFont(
 
     rFont.SetLanguage(eLang);
 
-    //  Groesse
+    //  Size
 
     if ( pOutDev != NULL )
     {
@@ -491,7 +491,7 @@ void ScPatternAttr::GetFont(
 
 void ScPatternAttr::FillToEditItemSet( SfxItemSet& rEditSet, const SfxItemSet& rSrcSet, const SfxItemSet* pCondSet )
 {
-    //  Items auslesen
+    //  Read Items
 
     SvxColorItem    aColorItem(EE_CHAR_COLOR);              // use item as-is
     SvxFontItem     aFontItem(EE_CHAR_FONTINFO);            // use item as-is
@@ -616,7 +616,7 @@ void ScPatternAttr::FillToEditItemSet( SfxItemSet& rEditSet, const SfxItemSet& r
             pItem = &rSrcSet.Get( ATTR_WRITINGDIR );
         eDirection = (SvxFrameDirection)static_cast<const SvxFrameDirectionItem*>(pItem)->GetValue();
     }
-    else        // alles direkt aus Pattern
+    else        // Everything directly from Pattern
     {
         aColorItem = static_cast<const SvxColorItem&>( rSrcSet.Get( ATTR_FONT_COLOR ) );
         aFontItem = static_cast<const SvxFontItem&>( rSrcSet.Get( ATTR_FONT ) );
@@ -668,7 +668,7 @@ void ScPatternAttr::FillToEditItemSet( SfxItemSet& rEditSet, const SfxItemSet& r
                         rSrcSet.Get( ATTR_WRITINGDIR )).GetValue();
     }
 
-    // kompatibel zu LogicToLogic rechnen, also 2540/1440 = 127/72, und runden
+    // Expect to be compatible to LogicToLogic, ie. 2540/1440 = 127/72, and round
 
     long nHeight = TwipsToHMM(nTHeight);
     long nCjkHeight = TwipsToHMM(nCjkTHeight);
@@ -811,9 +811,8 @@ void ScPatternAttr::GetFromEditItemSet( SfxItemSet& rDestSet, const SfxItemSet&
         switch ( static_cast<const SvxAdjustItem*>(pItem)->GetAdjust() )
         {
             case SVX_ADJUST_LEFT:
-                // EditEngine Default ist bei dem GetAttribs() ItemSet
-                // immer gesetzt!
-                // ob links oder rechts entscheiden wir selbst bei Text/Zahl
+                // EditEngine Default is always set in the GetAttribs() ItemSet !
+                // whether left or right, is decided in text / number
                 eVal = SVX_HOR_JUSTIFY_STANDARD;
                 break;
             case SVX_ADJUST_RIGHT:
@@ -847,8 +846,8 @@ void ScPatternAttr::GetFromEditItemSet( const SfxItemSet* pEditSet )
 
 void ScPatternAttr::FillEditParaItems( SfxItemSet* pEditSet ) const
 {
-    //  in GetFromEditItemSet schon dabei, in FillEditItemSet aber nicht
-    //  Hor. Ausrichtung Standard wird immer als "links" umgesetzt
+    //  already there in GetFromEditItemSet, but not in FillEditItemSet
+    //  Default horizontal alignmnet is always implemented as left
 
     const SfxItemSet& rMySet = GetItemSet();
 
@@ -955,7 +954,7 @@ static SfxStyleSheetBase* lcl_CopyStyleToPool
             }
         }
 
-        // ggF. abgeleitete Styles erzeugen, wenn nicht vorhanden:
+        // if necessary create derivative Styles, if not available:
 
         if ( ScGlobal::GetRscString(STR_STYLENAME_STANDARD) != aStrParent &&
              aStrSrcStyle != aStrParent &&
@@ -978,14 +977,14 @@ ScPatternAttr* ScPatternAttr::PutInPool( ScDocument* pDestDoc, ScDocument* pSrcD
     ScPatternAttr* pDestPattern = new ScPatternAttr(pDestDoc->GetPool());
     SfxItemSet* pDestSet = &pDestPattern->GetItemSet();
 
-    // Zellformatvorlage in anderes Dokument kopieren:
+    // Copy cell pattern style to other document:
 
     if ( pDestDoc != pSrcDoc )
     {
         OSL_ENSURE( pStyle, "Missing Pattern-Style! :-/" );
 
-        // wenn Vorlage im DestDoc vorhanden, dieses benutzen, sonst Style
-        // mit Parent-Vorlagen kopieren/ggF. erzeugen und dem DestDoc hinzufuegen
+        // if pattern in DestDoc is available, use this, otherwise copy
+        // parent style to style or create if necessary and attach DestDoc
 
         SfxStyleSheetBase* pStyleCpy = lcl_CopyStyleToPool( pStyle,
                                                             pSrcDoc->GetStyleSheetPool(),
@@ -1005,7 +1004,7 @@ ScPatternAttr* ScPatternAttr::PutInPool( ScDocument* pDestDoc, ScDocument* pSrcD
 
             if ( nAttrId == ATTR_VALIDDATA )
             {
-                //  Gueltigkeit ins neue Dokument kopieren
+                // Copy validity to the new document
 
                 sal_uLong nNewIndex = 0;
                 ScValidationDataList* pSrcList = pSrcDoc->GetValidationList();
@@ -1020,7 +1019,7 @@ ScPatternAttr* ScPatternAttr::PutInPool( ScDocument* pDestDoc, ScDocument* pSrcD
             }
             else if ( nAttrId == ATTR_VALUE_FORMAT && pDestDoc->GetFormatExchangeList() )
             {
-                //  Zahlformate nach Exchange-Liste
+                //  Number format to Exchange List
 
                 sal_uLong nOldFormat = static_cast<const SfxUInt32Item*>(pSrcItem)->GetValue();
                 SvNumberFormatterIndexTable::const_iterator it = pDestDoc->GetFormatExchangeList()->find(nOldFormat);
@@ -1166,7 +1165,7 @@ void ScPatternAttr::UpdateStyleSheet(ScDocument* pDoc)
 
 void ScPatternAttr::StyleToName()
 {
-    // Style wurde geloescht, Namen merken:
+    // Style was deleted, remember name:
 
     if ( pStyle )
     {
@@ -1196,13 +1195,13 @@ sal_uLong ScPatternAttr::GetNumberFormat( SvNumberFormatter* pFormatter ) const
     LanguageType eLang =
         static_cast<const SvxLanguageItem*>(&GetItemSet().Get( ATTR_LANGUAGE_FORMAT ))->GetLanguage();
     if ( nFormat < SV_COUNTRY_LANGUAGE_OFFSET && eLang == LANGUAGE_SYSTEM )
-        ;       // es bleibt wie es ist
+        ;       // it remains as it is
     else if ( pFormatter )
         nFormat = pFormatter->GetFormatForLanguageIfBuiltIn( nFormat, eLang );
     return nFormat;
 }
 
-//  dasselbe, wenn bedingte Formatierung im Spiel ist:
+// the same if conditional formatting is in play:
 
 sal_uLong ScPatternAttr::GetNumberFormat( SvNumberFormatter* pFormatter,
                                         const SfxItemSet* pCondSet ) const
@@ -1235,7 +1234,7 @@ const SfxPoolItem& ScPatternAttr::GetItem( sal_uInt16 nSubWhich, const SfxItemSe
     return GetItem( nSubWhich, GetItemSet(), pCondSet );
 }
 
-//  GetRotateVal testet vorher ATTR_ORIENTATION
+//  GetRotateVal is tested before ATTR_ORIENTATION
 
 long ScPatternAttr::GetRotateVal( const SfxItemSet* pCondSet ) const
 {
@@ -1267,7 +1266,7 @@ sal_uInt8 ScPatternAttr::GetRotateDir( const SfxItemSet* pCondSet ) const
             nRet = SC_ROTDIR_CENTER;
         else if ( eRotMode == SVX_ROTATE_MODE_TOP || eRotMode == SVX_ROTATE_MODE_BOTTOM )
         {
-            long nRot180 = nAttrRotate % 18000;     // 1/100 Grad
+            long nRot180 = nAttrRotate % 18000;     // 1/100 degrees
             if ( nRot180 == 9000 )
                 nRet = SC_ROTDIR_CENTER;
             else if ( ( eRotMode == SVX_ROTATE_MODE_TOP && nRot180 < 9000 ) ||


More information about the Libreoffice-commits mailing list
diff --git a/sc/source/core/data/fillinfo.cxx b/sc/source/core/data/fillinfo.cxx
index a0779f5..e0e2623 100644
--- a/sc/source/core/data/fillinfo.cxx
+++ b/sc/source/core/data/fillinfo.cxx
@@ -52,7 +52,7 @@ enum FillInfoLinePos
         FILP_RIGHT
     };
 
-//  aehnlich wie in output.cxx
+// Similar as in output.cxx
 
 static void lcl_GetMergeRange( SCsCOL nX, SCsROW nY, SCSIZE nArrY,
                             ScDocument* pDoc, RowInfo* pRowInfo,
@@ -68,7 +68,7 @@ static void lcl_GetMergeRange( SCsCOL nX, SCsROW nY, SCSIZE nArrY,
     SCCOL nLastCol;
     SCROW nLastRow;
 
-    while (bHOver)              // nY konstant
+    while (bHOver)              // nY constant
     {
         --rStartX;
         if (rStartX >= (SCsCOL) nX1 && !pDoc->ColHidden(rStartX, nTab, NULL, &nLastCol))
@@ -90,7 +90,7 @@ static void lcl_GetMergeRange( SCsCOL nX, SCsROW nY, SCSIZE nArrY,
         --rStartY;
 
         if (nArrY>0)
-            --nArrY;                        // lokale Kopie !
+            --nArrY;                        // local copy !
 
         if (rStartX >= (SCsCOL) nX1 && rStartY >= (SCsROW) nY1 &&
             !pDoc->ColHidden(rStartX, nTab, NULL, &nLastCol) &&
@@ -228,8 +228,8 @@ void ScDocument::FillInfo(
 
     bool bTabProtect = IsTabProtected(nTab);
 
-                                                // fuer Blockmarken von zusammengefassten Zellen mit
-                                                // versteckter erster Zeile / Spalte
+                                                // for block marks of merged cells
+                                                // with hidden first row/column
     bool bPaintMarks = false;
     bool bSkipMarks = false;
     SCCOL nBlockStartX = 0, nBlockEndX = 0;
@@ -244,7 +244,7 @@ void ScDocument::FillInfo(
             nBlockStartY = aTmpRange.aStart.Row();
             nBlockEndX = aTmpRange.aEnd.Col();
             nBlockEndY = aTmpRange.aEnd.Row();
-            ExtendHidden( nBlockStartX, nBlockStartY, nBlockEndX, nBlockEndY, nTab );   //? noetig ?
+            ExtendHidden( nBlockStartX, nBlockStartY, nBlockEndX, nBlockEndY, nTab );   //? needed ?
             if (pMarkData->IsMarkNegative())
                 bSkipMarks = true;
             else
@@ -252,7 +252,7 @@ void ScDocument::FillInfo(
         }
     }
 
-    //  zuerst nur die Eintraege fuer die ganze Spalte
+    // first only the entries for the entire column
 
     nArrRow=0;
     SCROW nYExtra = nRow2+1;
@@ -263,7 +263,7 @@ void ScDocument::FillInfo(
         if (nSignedY >= 0)
             nY = (SCROW) nSignedY;
         else
-            nY = MAXROW+1;          // ungueltig
+            nY = MAXROW+1;          // invalid
 
         if (nY > nDocHeightEndRow)
         {
@@ -276,7 +276,7 @@ void ScDocument::FillInfo(
         if ( nArrRow==0 || nDocHeight || nY > MAXROW )
         {
             RowInfo* pThisRowInfo = &pRowInfo[nArrRow];
-            pThisRowInfo->pCellInfo = NULL;                 // wird unten belegt
+            pThisRowInfo->pCellInfo = NULL;                 // is loaded below
 
             sal_uInt16 nHeight = (sal_uInt16) ( nDocHeight * fRowScale );
             if (!nHeight)
@@ -295,19 +295,19 @@ void ScDocument::FillInfo(
             if (nArrRow >= ROWINFO_MAX)
             {
                 OSL_FAIL("FillInfo: Range too big" );
-                nYExtra = nSignedY;                                 // Ende
-                nRow2 = nYExtra - 1;                                  // Bereich anpassen
+                nYExtra = nSignedY;                         // End
+                nRow2 = nYExtra - 1;                        // Adjust range
             }
         }
         else
-            if (nSignedY==(SCsROW) nYExtra)                         // zusaetzliche Zeile verdeckt ?
+            if (nSignedY==(SCsROW) nYExtra)                 // hidden additional line?
                 ++nYExtra;
     }
     nArrCount = nArrRow;                                      // incl. Dummys
 
-    //  rotierter Text...
+    // Rotated text...
 
-    //  Attribut im Dokument ueberhaupt verwendet?
+    // Is Attribute really used in document?
     bool bAnyItem = false;
     sal_uInt32 nRotCount = pPool->GetItemCount2( ATTR_ROTATE_VALUE );
     for (sal_uInt32 nItem=0; nItem<nRotCount; nItem++)
@@ -332,21 +332,21 @@ void ScDocument::FillInfo(
                 nRotMax = pRowInfo[nArrRow].nRotMaxCol;
     }
 
-    //  Zell-Infos erst nach dem Test auf gedrehte allozieren
-    //  bis nRotMax wegen nRotateDir Flag
+    //  Allocate cell information only after the test rotation
+    //  to nRotMax due to nRotateDir Flag
 
     for (nArrRow=0; nArrRow<nArrCount; nArrRow++)
     {
         RowInfo* pThisRowInfo = &pRowInfo[nArrRow];
         nY = pThisRowInfo->nRowNo;
-        pThisRowInfo->pCellInfo = new CellInfo[ nRotMax+1+2 ];  // vom Aufrufer zu loeschen !
+        pThisRowInfo->pCellInfo = new CellInfo[ nRotMax+1+2 ];  // to delete the caller!
 
-        for (nArrCol=0; nArrCol<=nRotMax+2; nArrCol++)                // Zell-Infos vorbelegen
+        for (nArrCol=0; nArrCol<=nRotMax+2; nArrCol++)          // Preassign cell info
         {
             if (nArrCol>0)
                 nX = nArrCol-1;
             else
-                nX = MAXCOL+1;      // ungueltig
+                nX = MAXCOL+1;      // invalid
 
             CellInfo* pInfo = &pThisRowInfo->pCellInfo[nArrCol];
             pInfo->bEmptyCellText = true;
@@ -368,9 +368,9 @@ void ScDocument::FillInfo(
             pInfo->bFilterActive = false;
             pInfo->nRotateDir   = SC_ROTDIR_NONE;
 
-            pInfo->bPrinted     = false;                    //  view-intern
-            pInfo->bHideGrid    = false;                    //  view-intern
-            pInfo->bEditEngine  = false;                    //  view-intern
+            pInfo->bPrinted     = false;                    //  view-internal
+            pInfo->bHideGrid    = false;                    //  view-internal
+            pInfo->bEditEngine  = false;                    //  view-internal
 
             pInfo->pBackground  = NULL;                     //TODO: omit?
             pInfo->pPatternAttr = NULL;
@@ -386,7 +386,7 @@ void ScDocument::FillInfo(
         }
     }
 
-    for (nArrCol=nCol2+3; nArrCol<=nRotMax+2; nArrCol++)            // restliche Breiten eintragen
+    for (nArrCol=nCol2+3; nArrCol<=nRotMax+2; nArrCol++)    // Add remaining widths
     {
         nX = nArrCol-1;
         if ( ValidCol(nX) )
@@ -406,9 +406,9 @@ void ScDocument::FillInfo(
     if(pCondFormList)
         pCondFormList->startRendering();
 
-    for (nArrCol=0; nArrCol<=nCol2+2; nArrCol++)                    // links & rechts + 1
+    for (nArrCol=0; nArrCol<=nCol2+2; nArrCol++)                    // left & right + 1
     {
-        nX = (nArrCol>0) ? nArrCol-1 : MAXCOL+1;                    // negativ -> ungueltig
+        nX = (nArrCol>0) ? nArrCol-1 : MAXCOL+1;                    // negative -> invalid
 
         if ( ValidCol(nX) )
         {
@@ -424,7 +424,7 @@ void ScDocument::FillInfo(
 
                 pRowInfo[0].pCellInfo[nArrCol].nWidth = nThisWidth;           //TODO: this should be enough
 
-                ScColumn* pThisCol = &maTabs[nTab]->aCol[nX];                   // Spalten-Daten
+                ScColumn* pThisCol = &maTabs[nTab]->aCol[nX];                   // Column data
 
                 nArrRow = 1;
                 // Iterate between rows nY1 and nY2 and pick up non-empty
@@ -433,24 +433,24 @@ void ScDocument::FillInfo(
                 sc::ParseAllNonEmpty(
                     pThisCol->maCells.begin(), pThisCol->maCells, nRow1, nRow2, aFunc);
 
-                if (nX+1 >= nCol1)                                // Attribute/Blockmarken ab nX1-1
+                if (nX+1 >= nCol1)                                // Attribute/Blockmark from nX1-1
                 {
                     ScAttrArray* pThisAttrArr = pThisCol->pAttrArray;       // Attribute
 
                     nArrRow = 0;
                     const ScPatternAttr* pPattern;
-                    SCROW nCurRow=nRow1;                  // einzelne Zeile
+                    SCROW nCurRow=nRow1;                  // single rows
                     if (nCurRow>0)
-                        --nCurRow;                      // oben 1 mehr
+                        --nCurRow;                      // 1 more on top
                     else
                         nArrRow = 1;
-                    nThisRow=nCurRow;                   // Ende des Bereichs
+                    nThisRow=nCurRow;                   // end of range
                     SCSIZE  nIndex;
                     (void) pThisAttrArr->Search( nCurRow, nIndex );
 
                     do
                     {
-                        nThisRow=pThisAttrArr->pData[nIndex].nRow;              // Ende des Bereichs
+                        nThisRow=pThisAttrArr->pData[nIndex].nRow;              // End of range
                         pPattern=pThisAttrArr->pData[nIndex].pPattern;
 
                         const SvxBrushItem* pBackground = static_cast<const SvxBrushItem*>(
@@ -481,7 +481,7 @@ void ScDocument::FillInfo(
                         bool bPivotPopupButton = ((nOverlap & SC_MF_BUTTON_POPUP) != 0);
                         bool bFilterActive = ((nOverlap & SC_MF_HIDDEN_MEMBER) != 0);
                         if (bMerged||bHOverlapped||bVOverlapped)
-                            bAnyMerged = true;                              // intern
+                            bAnyMerged = true;                              // internal
 
                         bool bHidden, bHideFormula;
                         if (bTabProtect)
@@ -506,7 +506,7 @@ void ScDocument::FillInfo(
                                 if ( GetPreviewCellStyle( nX, nCurRow, nTab  ) != NULL )
                                     bAnyPreview = true;
                                 RowInfo* pThisRowInfo = &pRowInfo[nArrRow];
-                                if (pBackground != pDefBackground)          // Spalten-HG == Standard ?
+                                if (pBackground != pDefBackground)          // Column background == Default ?
                                     pThisRowInfo->bEmptyBack = false;
                                 if (bContainsCondFormat)
                                     pThisRowInfo->bEmptyBack = false;
@@ -529,7 +529,7 @@ void ScDocument::FillInfo(
                                 pInfo->mpTLBRLine   = pTLBRLine;
                                 pInfo->mpBLTRLine   = pBLTRLine;
                                 pInfo->pShadowAttr  = pShadowAttr;
-                                //  nWidth wird nicht mehr einzeln gesetzt
+                                // nWidth is no longer set individually
 
                                 if (bScenario)
                                 {
@@ -612,17 +612,17 @@ void ScDocument::FillInfo(
 
                     if (pMarkData && pMarkData->IsMultiMarked())
                     {
-                        //  Blockmarken
+                        //  Block marks
                         const ScMarkArray* pThisMarkArr = pMarkData->GetArray()+nX;
                         nArrRow = 1;
-                        nCurRow = nRow1;                                      // einzelne Zeile
-                        nThisRow = nRow1;                                     // Ende des Bereichs
+                        nCurRow = nRow1;                                      // single rows
+                        nThisRow = nRow1;                                     // End of range
 
                         if ( pThisMarkArr->Search( nRow1, nIndex ) )
                         {
                             do
                             {
-                                nThisRow=pThisMarkArr->pData[nIndex].nRow;      // Ende des Bereichs
+                                nThisRow=pThisMarkArr->pData[nIndex].nRow;      // End of range
                                 const bool bThisMarked=pThisMarkArr->pData[nIndex].bMarked;
 
                                 do
@@ -654,7 +654,7 @@ void ScDocument::FillInfo(
                         }
                     }
                 }
-                else                                    // vordere Spalten
+                else                                    // columns in front
                 {
                     for (nArrRow=1; nArrRow+1<nArrCount; nArrRow++)
                     {
@@ -668,7 +668,7 @@ void ScDocument::FillInfo(
         }
         else
             pRowInfo[0].pCellInfo[nArrCol].nWidth = STD_COL_WIDTH;
         // STD_COL_WIDTH ganz links und rechts wird fuer DrawExtraShadow gebraucht
     }
 
     if(pCondFormList)
@@ -681,7 +681,7 @@ void ScDocument::FillInfo(
     {
         for (nArrRow=0; nArrRow<nArrCount; nArrRow++)
         {
-            for (nArrCol=nCol1; nArrCol<=nCol2+2; nArrCol++)                  // links und rechts einer mehr
+            for (nArrCol=nCol1; nArrCol<=nCol2+2; nArrCol++)                  // 1 more left and right
             {
                 CellInfo* pInfo = &pRowInfo[nArrRow].pCellInfo[nArrCol];
                 SCCOL nCol = (nArrCol>0) ? nArrCol-1 : MAXCOL+1;
@@ -703,14 +703,14 @@ void ScDocument::FillInfo(
                 {
                     const SfxPoolItem* pItem;
 
-                            //  Hintergrund
+                            // Background
                     if ( pCondSet->GetItemState( ATTR_BACKGROUND, true, &pItem ) == SfxItemState::SET )
                     {
                         pInfo->pBackground = static_cast<const SvxBrushItem*>(pItem);
                         pRowInfo[nArrRow].bEmptyBack = false;
                     }
 
-                            //  Umrandung
+                            // Border
                     if ( pCondSet->GetItemState( ATTR_BORDER, true, &pItem ) == SfxItemState::SET )
                         pInfo->pLinesAttr = static_cast<const SvxBoxItem*>(pItem);
 
@@ -719,7 +719,7 @@ void ScDocument::FillInfo(
                     if ( pCondSet->GetItemState( ATTR_BORDER_BLTR, true, &pItem ) == SfxItemState::SET )
                         pInfo->mpBLTRLine = static_cast< const SvxLineItem* >( pItem );
 
-                            //  Schatten
+                            //  Shadow
                     if ( pCondSet->GetItemState( ATTR_SHADOW, true, &pItem ) == SfxItemState::SET )
                     {
                         pInfo->pShadowAttr = static_cast<const SvxShadowItem*>(pItem);
@@ -735,9 +735,9 @@ void ScDocument::FillInfo(
         }
     }
 
-    //  bedingte Formatierung Ende
+    // End conditional formatting
 
-                //      Daten von zusammengefassten Zellen anpassen
+                //      Adjust data from merged cells
 
     if (bAnyMerged)
     {
@@ -746,7 +746,7 @@ void ScDocument::FillInfo(
             RowInfo* pThisRowInfo = &pRowInfo[nArrRow];
             nSignedY = nArrRow ? pThisRowInfo->nRowNo : ((SCsROW)nRow1)-1;
 
-            for (nArrCol=nCol1; nArrCol<=nCol2+2; nArrCol++)                  // links und rechts einer mehr
+            for (nArrCol=nCol1; nArrCol<=nCol2+2; nArrCol++)                  // 1 more left and right
             {
                 SCsCOL nSignedX = ((SCsCOL) nArrCol) - 1;
                 CellInfo* pInfo = &pThisRowInfo->pCellInfo[nArrCol];
@@ -763,7 +763,7 @@ void ScDocument::FillInfo(
                     const SfxItemSet* pStartCond = GetCondResult( nStartX,nStartY,nTab );
                     const SfxPoolItem* pItem;
 
-                    // Hintergrund kopieren (oder in output.cxx)
+                    // Copy Background (or in output.cxx)
 
                     if ( !pStartCond || pStartCond->
                                     GetItemState(ATTR_BACKGROUND,true,&pItem) != SfxItemState::SET )
@@ -771,7 +771,7 @@ void ScDocument::FillInfo(
                     pInfo->pBackground = static_cast<const SvxBrushItem*>(pItem);
                     pRowInfo[nArrRow].bEmptyBack = false;
 
-                    // Schatten
+                    // Shadow
 
                     if ( !pStartCond || pStartCond->
                                     GetItemState(ATTR_SHADOW,true,&pItem) != SfxItemState::SET )
@@ -780,7 +780,7 @@ void ScDocument::FillInfo(
                     if (pInfo->pShadowAttr != pDefShadow)
                         bAnyShadow = true;
 
-                    // Blockmarken - wieder mit Original-Merge-Werten
+                    // Block marks - again with the original merge values
 
                     bool bCellMarked = false;
                     if (bPaintMarks)
@@ -802,14 +802,14 @@ void ScDocument::FillInfo(
         }
     }
 
-    if (bAnyShadow)                             // Schatten verteilen
+    if (bAnyShadow)                             // distribute Shadow
     {
         for (nArrRow=0; nArrRow<nArrCount; nArrRow++)
         {
             bool bTop = ( nArrRow == 0 );
             bool bBottom = ( nArrRow+1 == nArrCount );
 
-            for (nArrCol=nCol1; nArrCol<=nCol2+2; nArrCol++)                  // links und rechts einer mehr
+            for (nArrCol=nCol1; nArrCol<=nCol2+2; nArrCol++)                  // 1 more left and right
             {
                 bool bLeft = ( nArrCol == nCol1 );
                 bool bRight = ( nArrCol == nCol2+2 );
@@ -819,7 +819,7 @@ void ScDocument::FillInfo(
                 SvxShadowLocation eLoc = pThisAttr ? pThisAttr->GetLocation() : SVX_SHADOW_NONE;
                 if (eLoc != SVX_SHADOW_NONE)
                 {
-                    //  oder Test auf != eLoc
+                    //  or test on != eLoc
 
                     SCsCOL nDxPos = 1;
                     SCsCOL nDxNeg = -1;
@@ -668,7 +668,7 @@ void ScDocument::FillInfo(
         else
             pRowInfo[0].pCellInfo[nArrCol].nWidth = STD_COL_WIDTH;
-        // STD_COL_WIDTH ganz links und rechts wird fuer DrawExtraShadow gebraucht
+        // STD_COL_WIDTH farthest to the left and right is needed for DrawExtraShadow
     }
 